@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Any;
 
-our $DATE = '2015-04-12'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2015-06-18'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -70,7 +70,7 @@ Perinci::CmdLine::Any - Choose Perinci::CmdLine implementation (::Lite or ::Clas
 
 =head1 VERSION
 
-This document describes version 0.10 of Perinci::CmdLine::Any (from Perl distribution Perinci-CmdLine-Any), released on 2015-04-12.
+This document describes version 0.11 of Perinci::CmdLine::Any (from Perl distribution Perinci-CmdLine-Any), released on 2015-06-18.
 
 =head1 SYNOPSIS
 
@@ -114,9 +114,10 @@ Either specify module name, or C<lite> or C<classic>.
 
 =head1 SEE ALSO
 
-L<Perinci::CmdLine::Lite>
+L<Perinci::CmdLine::Lite>, L<Perinci::CmdLine::Classic>
 
-L<Perinci::CmdLine::Classic>
+Another alternative backend, but not available through Perinci::CmdLine::Any
+since it works by generating script instead: L<Perinci::CmdLine::Inline>
 
 =head1 HOMEPAGE
 
